summaryrefslogtreecommitdiffstats
path: root/kword/KWPage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWPage.h')
-rw-r--r--kword/KWPage.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kword/KWPage.h b/kword/KWPage.h
index b650a383..b30a2ff9 100644
--- a/kword/KWPage.h
+++ b/kword/KWPage.h
@@ -102,20 +102,20 @@ public:
int pageNumber() const { return m_pageNum; }
/**
* return a QRect with the size of this page in pixels.
* @param zoomHandler the zoomhandler knows the current zoom levels. The KWDocument currently
* implements that interface.
*/
- QRect zoomedRect(KoZoomHandler *zoomHandler);
+ TQRect zoomedRect(KoZoomHandler *zoomHandler);
/// return a KoRect with the (pt) sizes of this page. Margins are ignored for this function.
const KoRect rect() const;
private:
/** private constructor, only for our friends
* @param parent the KWPageManager that we belong to.
* @param pageNum the number of the page as the user will see it.
*/
- KWPage(KWPageManager *parent, int pageNum);
+ KWPage(KWPageManager *tqparent, int pageNum);
int m_pageNum;
PageSideEnum m_pageSide;
KoPageLayout m_pageLayout;
@@ -102,20 +102,20 @@ public:
int pageNumber() const { return m_pageNum; }
/**
- * return a QRect with the size of this page in pixels.
+ * return a TQRect with the size of this page in pixels.
* @param zoomHandler the zoomhandler knows the current zoom levels. The KWDocument currently
* implements that interface.
@@ -102,20 +102,20 @@ public:
private:
/** private constructor, only for our friends
- * @param parent the KWPageManager that we belong to.
+ * @param tqparent the KWPageManager that we belong to.
* @param pageNum the number of the page as the user will see it.
*/